//
//  ViewController.m
//  BaiduCloudStorage
//
//  Created by 曾诗亮 on 2017/1/12.
//  Copyright © 2017年 zsl. All rights reserved.
//

#import "ViewController.h"
#import "Masonry.h"
#import "CategoryCell.h"

@interface ViewController () <UICollectionViewDataSource,UICollectionViewDelegate>

@property (strong, nonatomic) UIView *categoryView;
@property (strong, nonatomic) UIButton *categoryBtn;
@property (strong, nonatomic) UIImageView *arrowIV;

@property (strong, nonatomic) UIView *dropDownMenuView;

@property (strong, nonatomic) UIControl *control;

@property (strong, nonatomic) UICollectionView *collectionView;

@end

#define kWidth  [UIScreen mainScreen].bounds.size.width
#define kHeight [UIScreen mainScreen].bounds.size.height

#define kDuration 0.3

@implementation ViewController
{
    BOOL _isDropDownMenu;
    
    NSArray *_images;
    NSArray *_titles;
    
    NSInteger _index;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self prepareData];
    
    [self creatUI];
}

#pragma mark - private
- (void)prepareData
{
    _images = @[@"1",@"2",@"3",@"4",@"5",@"6",@"7",@"8"];
    _titles = @[@"全部",@"最近上传",@"图片",@"文档",@"视频",@"音乐",@"应用",@"其他"];
    _index = -1;
}

- (void)creatUI
{
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithCustomView:self.categoryView];
    [self arrowIV];
}

#pragma mark - <UICollectionViewDataSource>
- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section
{
    return 8;
}

- (__kindof UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath
{
    
    CategoryCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:@"cell" forIndexPath:indexPath];
    cell.imageView.image = [UIImage imageNamed:_images[indexPath.item]];
    cell.label.text = _titles[indexPath.item];
    
//    NSLog(@"_index: %ld", _index);
    if (indexPath.item == _index) {
        cell.label.textColor = [UIColor redColor];
        
    }else {
        cell.label.textColor = [UIColor blackColor];
    }

    return cell;
}

#pragma mark - <UICollectionViewDelegate>
- (void)collectionView:(UICollectionView *)collectionView didSelectItemAtIndexPath:(NSIndexPath *)indexPath
{
//    NSLog(@"item: %ld", indexPath.item);
    
    NSLog(@"title: %@", _titles[indexPath.item]);
    
    _index = indexPath.item;
    
    [self dismissControl];
}

#pragma mark - 懒加载
- (UIView *)categoryView
{
    if (!_categoryView) {
        _categoryView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 80, 30)];
    }
    return _categoryView;
}

- (UIButton *)categoryBtn
{
    if (!_categoryBtn) {
        _categoryBtn = [UIButton buttonWithType:UIButtonTypeCustom];
        [_categoryBtn setTitle:@"分类" forState:UIControlStateNormal];
        [self.categoryView addSubview:_categoryBtn];
        [_categoryBtn mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.bottom.mas_equalTo(0);
        }];
        [_categoryBtn addTarget:self action:@selector(clickCategoryBtn:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _categoryBtn;
}

- (void)clickCategoryBtn:(UIButton *)sender
{
//    NSLog(@"clickCategoryBtn");
    
    if (!_isDropDownMenu) {
        [UIView animateWithDuration:kDuration animations:^{
            self.control.alpha = 0.3f;
            self.dropDownMenuView.frame = CGRectMake(0, 64, kWidth, kHeight/4);
            self.dropDownMenuView.alpha = 1.0f;
            self.arrowIV.transform = CGAffineTransformRotate(self.arrowIV.transform, M_PI);
            
        }];
        _isDropDownMenu = YES;
        
        [self.collectionView reloadData];
        
    }else {
        [self dismissControl];
    }
}

- (UIImageView *)arrowIV
{
    if (!_arrowIV) {
        _arrowIV = [UIImageView new];
        _arrowIV.image = [UIImage imageNamed:@"arrow"];
        [self.categoryView addSubview:_arrowIV];
        [_arrowIV mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.mas_equalTo(self.categoryBtn.mas_right).mas_equalTo(10);
            make.centerY.mas_equalTo(self.categoryBtn);
        }];
    }
    return _arrowIV;
}

- (UIView *)dropDownMenuView
{
    if (!_dropDownMenuView) {
        _dropDownMenuView = [[UIView alloc] initWithFrame:CGRectMake(0, -(kHeight/4-64), kWidth, kHeight/4)];
        _dropDownMenuView.backgroundColor = [UIColor whiteColor];
        [self.view addSubview:self.dropDownMenuView];
    }
    return _dropDownMenuView;
}

- (UIControl *)control
{
    if (!_control) {
        _control = [UIControl new];
        _control.backgroundColor = [UIColor blackColor];
        _control.alpha = 0.0f;
        [self.view addSubview:_control];
        [_control mas_makeConstraints:^(MASConstraintMaker *make) {
            make.edges.mas_equalTo(0);
        }];
        [_control addTarget:self action:@selector(clickControl:) forControlEvents:UIControlEventTouchUpInside];
    }
    return _control;
}

- (void)clickControl:(UIControl *)sender
{
//    NSLog(@"clickControl");
    [self dismissControl];
}

- (void)dismissControl
{
    _isDropDownMenu = NO;
    
    [UIView animateWithDuration:kDuration animations:^{
        self.dropDownMenuView.frame = CGRectMake(0, -(kHeight/4-64), kWidth, kHeight/4);
        self.control.alpha = 0.0f;
        self.arrowIV.transform = CGAffineTransformRotate(self.arrowIV.transform, M_PI);
        self.dropDownMenuView.alpha = 0.0f;
    }];
}

- (UICollectionView *)collectionView
{
    if (!_collectionView) {
        UICollectionViewFlowLayout *flowLayout = [UICollectionViewFlowLayout new];
        _collectionView = [[UICollectionView alloc] initWithFrame:CGRectZero collectionViewLayout:flowLayout];
        flowLayout.itemSize = CGSizeMake(90, 85);
        //定义每个UICollectionView 横向的间距
        flowLayout.minimumLineSpacing = 0;
        //定义每个UICollectionView 纵向的间距
        flowLayout.minimumInteritemSpacing = 0;
        _collectionView.scrollEnabled = NO;
        _collectionView.dataSource = self;
        _collectionView.delegate = self;
        _collectionView.backgroundColor = [UIColor whiteColor];
        [self.dropDownMenuView addSubview:_collectionView];
        [_collectionView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.edges.mas_equalTo(0);
        }];
        
        [_collectionView registerNib:[UINib nibWithNibName:@"CategoryCell" bundle:nil] forCellWithReuseIdentifier:@"cell"];
    }
    return _collectionView;
}

@end
